@@ -14,11 +14,11 @@ A wrapper around 'deprecation' providing support for deprecated aliases.
 #
 
 # stdlib
+import datetime
 import functools
 import textwrap
 import warnings
-from datetime import date
-from typing import Optional
+from typing import Callable, Optional, Union
 
 # 3rd party
 import deprecation  # type: ignore
@@ -27,7 +27,7 @@ from packaging import version
 __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 __license__: str = "Apache Software License"
-__version__: str = "0.1.1"
+__version__: str = "0.2.0"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["deprecated"]
@@ -35,18 +35,19 @@ __all__ = ["deprecated"]
 
 def deprecated(
 		deprecated_in: Optional[str] = None,
-		removed_in: Optional[str] = None,
+		removed_in: Union[str, datetime.date, None] = None,
 		current_version: Optional[str] = None,
 		details: str = '',
-		name: Optional[str] = None
-		):
+		name: Optional[str] = None,
+		func: Optional[Callable] = None,
+		) -> Callable:
 	r"""Decorate a function to signify its deprecation.
 
 	This function wraps a method that will soon be removed and does two things:
 
 	* The docstring of the method will be modified to include a notice
 	  about deprecation, e.g., "Deprecated since 0.9.11. Use foo instead."
-	* Raises a :class:`~deprecation.DeprecatedWarning`
+	* Raises a :class:`deprecation.DeprecatedWarning`
 	  via the :mod:`warnings` module, which is a subclass of the built-in
 	  :class:`DeprecationWarning`. Note that built-in
 	  :class:`DeprecationWarning`\s are ignored by default, so for users
@@ -85,6 +86,12 @@ def deprecated(
 	:param name: The name of the deprecated function, if an alias is being
 		deprecated. Default is to the name of the decorated function.
 	:no-default name:
+
+	:param func: The function to deprecate. Can be used as an alternative to using the ``@deprecated(...)`` decorator.
+		If provided ``deprecated`` can't be used as a decorator.
+	:no-default func:
+
+	.. versionchanged:: 0.2.0  Added the ``func`` argument.
 	"""
 
 	# You can't just jump to removal. It's weird, unfair, and also makes
@@ -102,8 +109,8 @@ def deprecated(
 	# StrictVersion won't take a None or a "", so make whatever goes to it
 	# is at least *something*. Compare versions only if removed_in is not
 	# of type datetime.date
-	if isinstance(removed_in, date):
-		if date.today() >= removed_in:
+	if isinstance(removed_in, datetime.date):
+		if datetime.date.today() >= removed_in:
 			is_unsupported = True
 		else:
 			is_deprecated = True
@@ -143,14 +150,14 @@ def deprecated(
 			if removed_in:
 				# If removed_in is a date, use "removed on"
 				# If removed_in is a version, use "removed in"
-				if isinstance(removed_in, date):
+				if isinstance(removed_in, datetime.date):
 					parts["removed_in"] = f"\n   This will be removed on {removed_in}."
 				else:
 					parts["removed_in"] = f"\n   This will be removed in {removed_in}."
 			if details:
 				parts["details"] = f" {details}"
 
-			deprecation_note = (".. deprecated::{deprecated_in}{removed_in}{details}".format_map(parts))
+			deprecation_note = ".. deprecated::{deprecated_in}{removed_in}{details}".format_map(parts)
 
 			# default location for insertion of deprecation note
 			loc = 1
@@ -200,4 +207,7 @@ def deprecated(
 
 		return _inner
 
-	return _function_wrapper
+	if func is None:
+		return _function_wrapper
+	else:
+		return _function_wrapper(func)
